🦦 Clawless Core
clawless is an opinionated, batteries-included framework for building
command-line applications with Rust. It features low-level building blocks and
high-level abstractions that can be used to build stateless CLIs or stateful
TUI applications.
This crate, clawless-core, implements core types and traits that are used by
higher-level crates in the clawless ecosystem.
License
Licensed under either of
- Apache License, Version 2.0 (http://www.apache.org/licenses/LICENSE-2.0)
- MIT license (http://opensource.org/licenses/MIT)
at your option.
Contribution
Unless you explicitly state otherwise, any contribution intentionally submitted for inclusion in the work by you, as defined in the Apache-2.0 license, shall be dual licensed as above, without any additional terms or conditions.
Modules
- cancellation
- Cooperative shutdown
- context
- Context for Clawless commands
- event
- Event types for structured command output
- output
- Command output interface
- prelude
- A prelude module to easily import Clawless’s core types and traits