Module context

Module context 

Context for Clawless commands

This module defines the Context struct, which provides information about the environment that Clawless commands are executed in, access to shared resources like loggers, and configuration settings.

For information on the context that is available to commands, see the fields and methods of the Context struct as well as the types defined in this module.

Structs

Context
Context for Clawless commands
ContextBuilder
Use builder syntax to set the inputs and finish with build().
CurrentWorkingDirectory
The working directory in which a command was called

Enums

ContextError
Errors that can occur when constructing a Context