CurrentWorkingDirectory

Struct CurrentWorkingDirectory 

pub struct CurrentWorkingDirectory(/* private fields */);
The working directory in which a command was called

The current working directory is the directory from which Clawless commands are run. It is passed to commands via the Context struct, allowing commands to operate relative to this directory.

Please note that the path is not updated if commands manually change into another directory.

Implementations

Source

impl CurrentWorkingDirectory

pub fn new(path: PathBuf) -> Self

Create a new #ident

This method creates a new #ident from a PathBuf.

Example
use std::path::PathBuf;
use typed_fields::path;

path!(MyPath);

let path = MyPath::new(PathBuf::from("src"));
pub fn get(&self) -> &Path

Get the inner value of the #ident

This method returns a reference to the inner value of the #ident.

Source

impl CurrentWorkingDirectory

pub fn try_from_env() -> Result<CurrentWorkingDirectory, ContextError>

Creates a CurrentWorkingDirectory from the environment

This function retrieves the current working directory from the environment and creates a CurrentWorkingDirectory instance. If the current directory cannot be determined, an error is returned.

Errors

Returns std::io::Error if the current directory cannot be determined from the environment.